Repository of small UI and other utilities, install with

    pip install pythonista-uiutils

Included:

- uiutils.gridview.GridView - places subviews in grid that is optimized to show as even rectangles as possible
- uiutils.richlabel.RichLabel - use markup to create fancier labels
- uiutils.safearea.SafeAreaView - avoids edges on iPhones
- uiutils.sfsymbol.SymbolImage - use Apple SFSymbols as icon images. Repository root includes an icon browser.
